@@ -1,12 +1,12 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
 #include "ActionHandler.hpp"
 
@@ -30,7 +30,6 @@
 #include "CustomCommandDialog.hpp"
 #include "MenuHandler.hpp"
 #include "ServerHandler.hpp"
-#include "Str.hpp"
 #include "TextFormat.hpp"
 #include "UIDebug.hpp"
 #include "UiLog.hpp"
@@ -40,6 +39,7 @@
 #include "VNodeMover.hpp"
 #include "VNodeStateDiag.hpp"
 #include "VReportMaker.hpp"
+#include "ecflow/core/Str.hpp"
 
 #define _UI_ACTIONHANDLER_DEBUG
 
@@ -349,7 +349,7 @@ bool ActionHandler::confirmCommand(const std::vector<VInfo_ptr>& filteredNodes,
         ecf::Str::replace_all(question, placeholder, "<b>" + QString::number(taskNum).toStdString() + "</b>");
     }
 
-    QString msg        = QString::fromStdString(question);
+    QString msg = QString::fromStdString(question);
 
     QString warningStr = QString::fromStdString(warning);
     if (!warningStr.isEmpty()) {
