@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef EXPANDSTATENODE_HPP
-#define EXPANDSTATENODE_HPP
+#ifndef ecflow_viewer_ExpandStateNode_HPP
+#define ecflow_viewer_ExpandStateNode_HPP
 
 #include <string>
 #include <vector>
@@ -61,4 +61,4 @@ protected:
     unsigned int collapsedAll_ : 1;
 };
 
-#endif // EXPANDSTATENODE_HPP
+#endif /* ecflow_viewer_ExpandStateNode_HPP */
