@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef OUTPUTFETCHTASK_HPP
-#define OUTPUTFETCHTASK_HPP
+#ifndef ecflow_viewer_FetchTask_HPP
+#define ecflow_viewer_FetchTask_HPP
 
 #include <deque>
 #include <map>
@@ -29,7 +29,7 @@ class VReply;
 class FetchTaskFactory {
 public:
     explicit FetchTaskFactory(const std::string&);
-    virtual ~FetchTaskFactory()                             = default;
+    virtual ~FetchTaskFactory() = default;
 
     virtual AbstractFetchTask* make(FetchQueueOwner* owner) = 0;
     static AbstractFetchTask* create(const std::string& name, FetchQueueOwner* owner);
@@ -167,4 +167,4 @@ protected:
 std::ostream& operator<<(std::ostream&, AbstractFetchTask*);
 std::ostream& operator<<(std::ostream&, FetchQueue*);
 
-#endif // OUTPUTFETCHTASK_HPP
+#endif /* ecflow_viewer_FetchTask_HPP */
