@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef VIEWER_SRC_NODEQUERYENGINE_HPP_
-#define VIEWER_SRC_NODEQUERYENGINE_HPP_
+#ifndef ecflow_viewer_NodeQueryEngine_HPP
+#define ecflow_viewer_NodeQueryEngine_HPP
 
 #include <string>
 #include <vector>
@@ -95,4 +95,4 @@ private:
     VNode* rootNode_{nullptr};
 };
 
-#endif /* VIEWER_SRC_NODEQUERYENGINE_HPP_ */
+#endif /* ecflow_viewer_NodeQueryEngine_HPP */
