@@ -1,14 +1,15 @@
-/***************************** LICENSE START ***********************************
+/*
+ * Copyright 2009- ECMWF and INPE.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
- Copyright 2009- ECMWF and INPE. This software is distributed under the terms
- of the Apache License version 2.0. In applying this license, ECMWF does not
- waive the privileges and immunities granted to it by virtue of its status as
- an Intergovernmental Organization or submit itself to any jurisdiction.
-
- ***************************** LICENSE END *************************************/
-
-#ifndef TABLENODEWIDGET_HPP_
-#define TABLENODEWIDGET_HPP_
+#ifndef ecflow_viewer_TableNodeWidget_HPP
+#define ecflow_viewer_TableNodeWidget_HPP
 
 #include "NodeWidget.hpp"
 #include "ui_TableNodeWidget.h"
@@ -45,4 +46,4 @@ private:
     QAction* acAutoScroll_;
 };
 
-#endif
+#endif /* ecflow_viewer_TableNodeWidget_HPP */
