@@ -1,14 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef TEXTFILTERHANDLERDIALOG_HPP
-#define TEXTFILTERHANDLERDIALOG_HPP
+#ifndef ecflow_viewer_TextFilterHandlerDialog_HPP
+#define ecflow_viewer_TextFilterHandlerDialog_HPP
 
 #include <QDialog>
 
@@ -75,4 +76,4 @@ private:
     int applyIndex_{-1};
 };
 
-#endif // TEXTFILTERHANDLERDIALOG_HPP
+#endif /* ecflow_viewer_TextFilterHandlerDialog_HPP */
