@@ -1,12 +1,12 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
 #include "VProperty.hpp"
 
@@ -17,11 +17,10 @@
     #include <QtCore5Compat/QRegExp>
 #endif
 
-#include <boost/algorithm/string.hpp>
-
 #include "Sound.hpp"
 #include "UserMessage.hpp"
 #include "ViewerUtil.hpp"
+#include "ecflow/core/Str.hpp"
 
 VProperty::VProperty(const std::string& name)
     : strName_(name),
@@ -161,7 +160,7 @@ void VProperty::setValue(QVariant val) {
 
     bool changed = (value_ != val);
 
-    value_       = val;
+    value_ = val;
 
     if (changed)
         dispatchChange();
@@ -331,7 +330,7 @@ VProperty* VProperty::find(const std::string& fullPath) {
         return this;
 
     std::vector<std::string> pathVec;
-    boost::split(pathVec, fullPath, boost::is_any_of("."));
+    ecf::algorithm::split(pathVec, fullPath, ".");
 
     if (pathVec.size() > 0) {
         if (pathVec.at(0) != strName_)
@@ -409,7 +408,7 @@ void VProperty::setUseMaster(bool b) {
 }
 
 VProperty* VProperty::clone(bool addLink, bool setMaster, bool useMaster) {
-    auto* cp          = new VProperty(strName_);
+    auto* cp = new VProperty(strName_);
 
     cp->value_        = value_;
     cp->defaultValue_ = defaultValue_;
