@@ -613,7 +613,7 @@ const char* AlterCmd::desc() {
            "       For change:\n"
            "         [ variable | clock_type | clock_gain | clock_date | clock_sync  | event | meter | label |\n"
            "           trigger  | complete   | repeat     | limit_max  | limit_value | defstatus | late | time |\n"
-           "           today, aviso, mirror ]\n"
+           "           today | aviso | mirror ]\n"
            "         *NOTE* If the clock is changed, then the suite will need to be re-queued in order for\n"
            "         the change to take effect fully.\n"
            "       For add:\n"
@@ -640,6 +640,9 @@ const char* AlterCmd::desc() {
            "   * for mirror, \"--listener '{ \\\"event\\\": \\\"mars\\\", \\\"request\\\": { \\\"class\\\": \"od\" } }'\n"
            "                  --url http://aviso/ --schema /path/to/schema --polling 60\"\n"
            "\n"
+           "For both aviso and mirror, the special value \"reload\" can be used to force reloading the configuration.\n"
+           "  n.b. This is typically useful after updating variables used to configure these kind of attributes.\n"
+           "\n"
            "Usage:\n\n"
            "   ecflow_client --alter=add variable GLOBAL \"value\" /           # add server variable\n"
            "   ecflow_client --alter=add variable FRED \"value\" /path/to/node # add node variable\n"
